AgentRuntime

Struct AgentRuntime 

pub struct AgentRuntime { /* private fields */ }

Implementations

Source

impl AgentRuntime

pub fn new(store: Arc<dyn SessionStore>) -> Self

pub async fn create_session( &self, request: CreateSessionRequest, ) -> Result<SessionRecord, KaynineError>

pub async fn list_sessions(&self) -> Result<Vec<SessionRecord>, KaynineError>

pub async fn list_branches( &self, session_id: &SessionId, ) -> Result<Vec<BranchRecord>, KaynineError>

pub async fn get_snapshot( &self, session_id: &SessionId, ) -> Result<SessionSnapshot, KaynineError>

pub async fn start_run( &self, request: StartRunRequest, ) -> Result<RunAccepted, KaynineError>

pub async fn cancel( &self, request: CancelRequest, ) -> Result<CancelOutcome, KaynineError>

pub async fn watch_session( &self, session_id: &SessionId, ) -> Result<SessionSubscription, KaynineError>

Watches a session. Spawns (or reuses) the session actor, so if another process holds the writer lease this returns SessionBusy — v0.1 targets single-process desktop use, where multi-process watching can read the store directly instead of via a live feed.

pub async fn steer( &self, request: SteerRequest, ) -> Result<SteerAccepted, KaynineError>

pub async fn resolve_approval( &self, request: ApprovalResolution, ) -> Result<ApprovalOutcome, KaynineError>

pub async fn update_session( &self, request: UpdateSessionRequest, ) -> Result<SessionRecord, KaynineError>

pub async fn release_session( &self, session_id: &SessionId, ) -> Result<ReleaseOutcome, KaynineError>

pub async fn shutdown( &self, grace: Duration, ) -> Result<ShutdownReport, KaynineError>